@@ -98,7 +98,8 @@ update_general_page (GladeXML *xml)
 	w = glade_xml_get_widget (xml, "printer_image");
 	gtk_image_set_from_pixbuf (GTK_IMAGE (w), pixbuf);
 
-	label_vs_entry (xml, "name_entry", "name_label",
+	w = glade_xml_get_widget (xml, "name_label");
+	gtk_label_set_text (GTK_LABEL (w),
 		gnome_cups_printer_get_name (printer));
 	label_vs_entry (xml, "description_entry", "description_label",
 		gnome_cups_printer_get_description (printer));
@@ -123,9 +124,7 @@ cb_entry_idle_handler (EntryHandlerInfo *data)
 
 	g_return_val_if_fail (name != NULL, FALSE);
 
-	if (0 == strcmp (name, "name_entry"))
-		gnome_cups_printer_set_name (data->printer, data->value, NULL);
-	else if (0 == strcmp (name, "description_entry"))
+	if (0 == strcmp (name, "description_entry"))
 		gnome_cups_printer_set_description (data->printer, data->value, NULL);
 	else if (0 == strcmp (name, "location_entry"))
 		 gnome_cups_printer_set_location (data->printer, data->value, NULL);
@@ -140,29 +139,34 @@ cb_entry_idle_handler (EntryHandlerInfo *data)
 /* You can't hit the main loop in a GtkEntry's focus_out_event, so queue this
  * in an idle handler */
 static gboolean
-cb_entry_changed (GladeXML *xml, GtkWidget *entry)
+cb_entry_activated (GtkEntry *entry, GladeXML *xml)
 {
 	EntryHandlerInfo *data = g_new0 (EntryHandlerInfo, 1);
 	GnomeCupsPrinter *printer = g_object_get_data (G_OBJECT (xml), "printer");
 	g_object_ref (printer);
 	data->printer = printer;
-	data->value = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
-	data->entry = entry;
+	data->value = g_strdup (gtk_entry_get_text (entry));
+	data->entry = GTK_WIDGET (entry);
 	g_idle_add ((GSourceFunc)cb_entry_idle_handler, data);
 	return FALSE;
 }
+static gboolean
+cb_entry_lost_focus (GtkEntry *entry, G_GNUC_UNUSED GdkEventFocus *event,
+		     GladeXML *xml)
+{
+	return cb_entry_activated (entry, xml);
+}
 
 static void
 setup_entry (GladeXML *xml, char const *name)
 {
 	GtkWidget *w = glade_xml_get_widget (xml, name);
-	g_signal_connect_swapped (w, "focus_out_event",
-		G_CALLBACK (cb_entry_changed), xml);
+	g_signal_connect (w, "focus_out_event",
+		G_CALLBACK (cb_entry_lost_focus), xml);
 	g_signal_connect (w, "activate",
-		G_CALLBACK (cb_entry_changed), xml);
+		G_CALLBACK (cb_entry_activated), xml);
 }
 
-
 static void
 check_toggled_cb (GtkWidget *widget,
 		  gpointer user_data)
@@ -347,7 +351,6 @@ setup_general_page (GladeXML *xml)
 	update_general_page (xml);
 
 	if (gnome_cups_can_admin ()) {
-		setup_entry (xml, "name_entry");
 		setup_entry (xml, "description_entry");
 		setup_entry (xml, "location_entry");
 	}
