@@ -454,6 +454,13 @@ setup_ppd (GCupsDriverSelector *ds, GCupsPPD *ppd, gboolean select)
 		GtkTreeIter   iter;
 		GtkComboBox  *combo = GTK_COMBO_BOX (glade_xml_get_widget (ds->xml, "drivers"));
 		GtkTreeModel *store = gtk_combo_box_get_model (combo);
+
+		if (NULL == store) {
+			store = (GtkTreeModel *)gtk_list_store_new (4,
+				G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_STRING, GDK_TYPE_PIXBUF);
+			gtk_combo_box_set_model (combo, store);
+		}
+
 		gtk_list_store_append (GTK_LIST_STORE (store), &iter);
 		if (ppd->is_recommended)
 			pixbuf = gtk_widget_render_icon (GTK_WIDGET (combo),
@@ -463,7 +470,7 @@ setup_ppd (GCupsDriverSelector *ds, GCupsPPD *ppd, gboolean select)
 		gtk_list_store_set (GTK_LIST_STORE (store), &iter,
 			0, ppd->driver,
 			1, ppd,
-			2, ppd->is_recommended,
+			2, ppd->is_recommended ? _("(Suggested)") : "",
 			3, pixbuf,
 			-1);
 	}
@@ -1028,7 +1035,11 @@ gcups_driver_selector_get (GCupsDriverSelector *ds)
 void
 gcups_driver_selector_set_nickname (GCupsDriverSelector *ds, const char *nickname)
 {
-	GCupsPPD *ppd = get_detected_ppd (ds, nickname);
+	GCupsPPD *ppd;
+
+	g_return_if_fail (ds != NULL);
+
+	ppd = get_detected_ppd (ds, nickname);
 	if (ppd != NULL) {
 		combo_select (ds->xml, "vendors", 0, ppd->vendor);
 		select_model (ds->xml, ppd->model);
